.. -*- mode: rst; fill-column: 78; indent-tabs-mode: nil -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the PyMVPA package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###


.. index:: Who is using it?, Publications
.. _chap_whoisusingit:

****************
Who Is Using It?
****************


.. only:: html

  If you are using PyMVPA or have published a study employing it, please leave a
  comment at the bottom of this page, if you want to be listed here as well.


Institutions Where PyMVPA Is Known To Be Used
=============================================

* Center for Mind/Brain Sciences, **University of Trento**, Italy
* Department of Psychological and Brain Sciences, **Dartmouth College**, USA
* Thayer School of Engineering, **Dartmouth College**, USA
* Department of Psychology & Neuroscience, **Duke University**, USA
* **Fondazione Bruno Kessler**, Italy
* Department of Brain and Cognitive Sciences, **Massachusetts Institute of
  Technology**, USA
* Department of Neurology, **Max Planck Insititute for Neurological Research**,
  Cologne, Germany
* **MRC Cognition and Brain Sciences Unit**, Cambridge, UK
* Department of Experimental Psychology, **Otto-von-Guericke-University
  Magdeburg**, Germany
* Donders Center for Cognition, **Radboud University Nijmegen**, Netherlands
* Department of Psychology, **University of California at Los Angeles**, USA
* Center for Functional Neuroimaging, **University of Pennsylvania**, USA
* Brain & Creativity Institute, **University of Southern California**, USA
* Imaging Research Center, **University of Texas at Austin**, USA
* Department of Psychiatry, **University of Wisconsin, Madison**, USA
* Department of Psychology, **Yale University**, USA

...and many more (stopped extending this list in 2012).


Studies employing PyMVPA
========================

2016
----

* :ref:`Guntupalli et al., Cerebral Cortex (2016) <GHH+16>`.
  A Model of Representational Spaces in Human Cortex

* Watson et al., NeuroImage (2016). Spatial properties of objects predict
  patterns of neural response in the ventral visual pathway

* Watson et al., NeuroImage (2016). Patterns of neural response in
  scene-selective regions of the human brain are affected by low-level
  manipulations of spatial frequency

2015
----

* Floren et al., Frontiers in Human Neuroscience (2015). Accurately decoding
  visual information from fMRI data obtained in a realistic virtual environment

* Merkel et al, NeuroImage (2015). Neural correlates of multiple object
  tracking strategies

* Pogoda, et al., Brain and Cognition (2015). Multivariate representation of
  food preferences in the human brain

* Emmerling et al., NeuroImage (2015). Decoding the direction of imagined
  visual motion using 7 T ultra-high field fMRI

* Danelli et al., Frontiers in Psychology (2015). Framing effects reveal
  discrete lexical-semantic and sublexical procedures in reading: an fMRI study

* Schlegel et al., NeuroImage (2015). The artist emerges: Visual art learning
  alters neural structure and function

* Maass et al., ELife (2015). Functional subregions of the human entorhinal
  cortex

* Sha et al., Journal of Cognitive Neuroscience (2015). The Animacy Continuum
  in the Human Ventral Vision Pathway

* :ref:`Greisel et al., arXiv (2015) <GSD+15>`. Photometric redshifts and
  model spectral energy distributions of galaxies from the SDSS-III BOSS DR10
  data

* :ref:`McNamee et al., Journal of Neuroscience (2015) <McMLZ+15>`. Characterizing
  the associative content of brain structures involved in habitual and
  goal-directed actions in humans: a multivariate fMRI study

* :ref:`Cole et al., Cerebral Cortex (2015) <CIB15>`. The behavioral relevance
  of task information in human prefrontal cortex

* :ref:`Guo and Meng, NeuroImage (2015) <GM15>`. The encoding of
  category-specific versus nonspecific information in human inferior temporal
  cortex


2014
----

* :ref:`Rueschemeyer et al., Journal of Cognitive Neuroscience (2014)
  <REA+14>`. Observing, performing, and understanding actions: Revisiting
  the role of cortical motor areas in processing of action words.

* :ref:`Hanke et al., Scientific Data (2014) <HBI+14>`. A high-resolution
  7-Tesla fMRI dataset from complex natural stimulation with an audio movie.

* :ref:`Helfinstein et al., PNAS (2014) <HSC+14>`. Predicting risky choices from
  brain activity patterns.

* :ref:`Sha et al., Journal of Cognitive Neuroscience (2014) <SHA+14>`. The
  animacy continuum in the human ventral vision pathway

* :ref:`Schönwiesner et al., Cerebral Cortex (2014) <SDV+14>`. Parcellation of
  Human and Monkey core auditory cortex with fMRI pattern classification and
  objective detection of tonotopic gradient reversals

* :ref:`Klein and Zatorre, Cerebral Cortex (2014) <KZ14>`. Representations of
  invariant musical categories are decodable by pattern analysis of locally
  distributed BOLD responses in superior temporal and intraparietal sulci

* :ref:`Huffman and Start, Hippocampus (2014) <HS14>`. Multivariate pattern
  analysis of the human medial temporal lobe revealed representationally
  categorical cortex and representationally agnostic hippocampus

* :ref:`Schlegel et al., NeuroImage (2014) <SAF+15>`. The artist emerges:
  Visual art learning alters neural structure and function

* :ref:`Jimura et al, Frontiers in Human Neuroscience (2014) <JCS+14>`. The
  neural basis of task switching changes with skill acquisition

* :ref:`Lee and McCarthy, Cerebral Cortex (2014) <LMcC14>`. Functional
  Heterogeneity and Convergence in the Right Temporoparietal Junction

* :ref:`Watson et al., NeuroImage (2014) <WHA14>`. Patterns of response to
  visual scenes are linked to the low-level properties of the image

* :ref:`Schlichting and Preston, PNAS (2014) <SP14>`. Memory reactivation
  during rest supports upcoming learning of related content

* :ref:`Mittner et al., Journal of Neuroscience (2014) <MBT+14>`. When the
  brain takes a break: A model-based analysis of mind wandering

* :ref:`Wang et al., Journal of Neuroscience (2014) <WLM+14>`. Distributed
  Value Representation in the Medial Prefrontal Cortex during Intertemporal
  Choices

* :ref:`Parkinson et al., Journal of Neuroscience (2014) <PLW14>`. A common
  cortical metric for spatial, temporal, and social distance

* :ref:`Kim et al., Frontiers in Human Neuroscience (2014)
  <KLE+14>`. Discriminable spatial patterns of activation for faces and bodies
  in the fusiform gyrus

* :ref:`Pollmann et al., NeuroImage (2014) <PZB+14>`. The right
  temporo-parietal junction contributes to visual feature binding

* :ref:`Fogelson et al., Frontiers in Psychology (2014) <FKM+14>`. Unconscious
  neural processing differs with method used to render stimuli invisible

* :ref:`Plitt et al., Social Neuroscience (2014) <PSE14>`. Are corporations
  people too? The neural correlates of moral judgments about companies and
  individuals

* :ref:`Kubilius et al., Journal of Vision (2014) <KWO14>`. Encoding of
  configural regularity in the human visual system

* :ref:`Heitmeyer et al., Automated Software Engineering (2014)
  <HPL+14>`. Building high assurance human-centric decision systems


2013
----

* :ref:`Anderson et al., Clinical Neuropsychology (2013) <ARV+13>`. 7T fMRI
  reveals feasibility of covert visual attention-based brain–computer
  interfacing with signals obtained solely from cortical grey matter accessible
  by subdural surface electrodes

* :ref:`Manelis and Reder, Cerebral Cortex (2013) <MR13>`.
  he who is well prepared has half won the battle: an fMRI study of task
  preparation

* :ref:`Kohler et al., NeuroImage (2013) <KFR+13>`. Pattern classification
  precedes region-average hemodynamic response in early visual cortex.

* :ref:`Hassabis et al., Cerebral Cortex (2013) <HSN+13>`. Imagine all the
  people: How the brain creates and uses personality models to predict behavior.

* :ref:`Smith et al., PNAS (2013) <SCR+13>`. Decoding the anatomical network
  of spatial attention.

* :ref:`Lescroart and Biederman, Cerebral Cortex (2013) <LB13>`. Cortical
  representation of medial axis structure.

* :ref:`Strnad et al., PloS one (2013) <SPB+13>`. Multivoxel Pattern Analysis
  Reveals Auditory Motion Information in MT+ of Both Congenitally Blind and
  Sighted Individuals.

* :ref:`Baumgartner et al., NeuroImage (2013) <BHG+13>`. Evidence for feature
  binding in the superior parietal lobule.

* :ref:`McNamee et al., Nature Neuroscience (2013) <MRO13>`. Category-dependent
  and category-independent goal-value codes in human ventromedial prefrontal
  cortex.

* :ref:`Liang, et al., Nature Communications (2013) <LMH+13>`. Primary sensory
  cortices contain distinguishable spatial patterns of activity for each sense.

2012
----

.. cummulative impact this year: 81.406

* :ref:`Viswanathan et al., arXiv preprint (2012) <VCG12>`. On the geometric
  structure of fMRI searchlight-based information maps.

* :ref:`Farrell et al., Biochemistry (2012) <FWJ+12>`. Toward Fast Determination
  of Protein Stability Maps: Experimental and Theoretical Analysis of Mutants
  of a Nocardiopsis prasina Serine Protease.

* :ref:`Sobhani et al., PloS one (2012) <SFK+12>`. Interpersonal liking
  modulates motor-related neural regions.

* :ref:`Kingson et al., Journal of Neuroscience (2012) <KKD+12>`. Sight and
  Sound Converge to Form Modality-Invariant Representations in Temporoparietal
  Cortex.

* :ref:`Kaplan and Meyer, NeuroImage (2012) <KM12>`. Multivariate pattern
  analysis reveals common neural patterns across individuals during touch
  observation.

* :ref:`Carter et al., Science (2012) <CBR+12>`. A distinct role of the
  temporal-parietal junction in predicting socially guided decisions.

* :ref:`van der Laan, PloS one (2012) <vdL+12>`. Appearance matters: neural
  correlates of food choice and packaging aesthetics.

* :ref:`Merrill et al., Frontiers in Psychology (2012) <MSB+12>`.
  Perception of words and pitch patterns in song and speech.

* :ref:`Ekman et al., PNAS (2012) <EDT+12>`. Predicting errors from
  reconfiguration patterns in human brain networks.

* :ref:`Hiroyuki et al., Frontiers in Neuroinformatics (2012) <HBL+12>`:
  Decoding Semantics across fMRI sessions with Different Stimulus Modalities:
  A practical MVPA Study.

* :ref:`Gorlin et al., PNAS (2012) <GMS+12>`: Imaging prior information in the
  brain.

* :ref:`Raizada and Connolly, Cognitive Neuroscience (2012) <RC12>`: What
  makes different people's representations alike: neural similarity-space
  solves the problem of across-subject fMRI decoding.
  `Preprint PDF and code <http://raizadalab.org/publications.html>`__ are available

* :ref:`Connolly et al., Journal of Neuroscience (2012) <CGG+12>`:
  Representation of Biological Classes in the Human Brain.

2011
----

.. cummulative impact this year: 75.619

* :ref:`Cole et al, Frontiers in Human Neuroscience (2011) <CEZ+11>`. Rapid
  Transfer of Abstract Rules to Novel Contexts in Human Lateral Prefrontal
  Cortex.

* :ref:`Vickery et al, Neuron (2011) <VCL11>`. Ubiquity and Specificity of
  Reinforcement Signals throughout the Human Brain.

* :ref:`Duff et al., NeuroImage (2011) <DTM+11>`: Task-driven ICA feature
  generation for accurate and interpretable prediction using fMRI.

* :ref:`Haxby et al., Neuron (2011) <HGC+11>`: A common, high-dimensional model
  of the representational space in human ventral temporal cortex.

* :ref:`Jimura and Poldrack, Neuropsychologia (2011) <JP11>`: Analyses of
  regional-average activation and multivoxel pattern information tell
  complementary stories

* :ref:`Carlin et al., Current Biology (2011) <CCK+11>`: A head view-invariant
  representation of gaze direction in anterior superior temporal sulcus

* :ref:`Kaunitz et al., Frontiers in Perception Science (2011) <KKO+11>`:
  Intercepting the first pass: rapid categorization is suppressed for unseen stimuli.

* :ref:`Carlin et al., Cerebral Cortex (2011) <CRK+11>`:
  Direction-Sensitive Codes for Observed Head Turns in Human Superior Temporal
  Sulcus.

* :ref:`Kubilius et al., Psychological Science (2011) <KWO11>`:
  Emergence of perceptual gestalts in the human visual cortex: The case of the
  configural superiority effect.
  `Complete suite of sources from stimuli delivery (PsychoPy) to data analysis (PyMVPA) <https://bitbucket.org/qbilius/confsup>`__
  is available

* :ref:`Manelis et al., Cerebral Cortex (2011) <MRH11>`: Dynamic Changes In
  The Medial Temporal Lobe During Incidental Learning Of Object–Location
  Associations.

* :ref:`Meyer et al., Cerebral Cortex (2011) <MKE+11>`: Seeing Touch Is
  Correlated with Content-Specific Activity in Primary Somatosensory Cortex.

2010
----

.. cummulative impact this year: 34.078

* :ref:`Woolgar et al., NeuroImage (2010) <WTB+10>`: Multi-voxel coding of
  stimuli, rules, and responses in human frontoparietal cortex.

* :ref:`Clithero et al., NeuroImage (2010) <CSM+10>`: Within- and
  cross-participant classifiers reveal different neural coding of information.

* :ref:`Gilliam et al., Proceedings of the International Conference on Pattern
  Recognition (2010) <GWC10>`: Scribe Identification in Medieval English
  Manuscripts.

* :ref:`Cohen at al., Frontiers in Human Neuroscience (2010) <CAS+10>`: Decoding
  Developmental Differences and Individual Variability in Response Inhibition
  Through Predictive Analyses Across Individuals.

* :ref:`Meyer et al., Nature Neuroscience (2010) <MKE10>`: Predicting visual
  stimuli based on activity in auditory cortices.

* :ref:`Manelis et al., Human Brain Mapping (2010) <MHH10>`: Implicit memory
  for object locations depends on reactivation of encoding-related brain
  regions.

2009
----

.. cummulative impact this year: 11.98

* :ref:`Trautmann et al., IEEE/RSJ International Conference on Intelligent
  Robots and Systems (2009) <TRL09>`: Development of an autonomous robot for
  ground penetrating radar surveys of polar ice.

* :ref:`Sun et al., Biological Psychiatry (2009) <SET+09>`: Elucidating an
  MRI-Based Neuroanatomic Biomarker for Psychosis: Classification Analysis
  Using Probabilistic Brain Atlas and Machine Learning Algorithms.


Articles referring to PyMVPA
============================

2014
----

* :ref:`Haxby et al, Annual review of neuroscience (2014) <HCG15>`. Decoding
  neural representational spaces using multivariate pattern analysis

* :ref:`Avants et al, NeuroImage (2014) <ALR+14>`. Sparse canonical
  correlation analysis relates network-level atrophy to multivariate cognitive
  measures in a neurodegenerative population

2013
----

* :ref:`Adluru et al., Neuroinformatics (2013) <AHL+13>`. Penalized likelihood
  phenotyping: unifying voxelwise analyses and multi-voxel pattern analyses in
  neuroimaging: penalized likelihood phenotyping.

* :ref:`Schrouff et al., Neuroinformatics (2013) <SRR+13>`. PRoNTo: Pattern
  Recognition for Neuroimaging Toolbox.

2012
----

* :ref:`Albanese et al., arXiv preprint (2012) <AVM+12>`. mlpy: machine learning
  Python.

* :ref:`Stelzer and Turner, NeuroImage (2012) <ST12>`. Statistical inference
  and multiple testing correction in classification-based multi-voxel pattern
  analysis (MVPA): Random permutations and cluster size control.

2011
----

* :ref:`Meyer and Kaplan, Journal of Visualized Experiments (2011) <MK11>`.
  Cross-Modal Multivariate Pattern Analysis.

* :ref:`Hollmann et al, PloS one (2011) <HRB+11>`. Predicting decisions in human
  social interactions using real-time fMRI and pattern classification.

* :ref:`Hanson and Schmidt, NeuroImage (2011) <HS11>`. High-resolution imaging
  of the fusiform face area (FFA) using multivariate non-linear classifiers
  shows diagnosticity for non-face categories.

* :ref:`Pereira and Botvinick, NeuroImage (2011) <PB11>`. Information mapping
  with pattern classifiers: a comparative study.

* :ref:`Pedregosa et al., The Journal of Machine Learning Research (2011)
  <PVG+11>`. Scikit-learn: Machine Learning in Python.

* :ref:`Pernet et al., Front. Psychology (2011) <PSR11>`. Single-trial analyses:
  why bother?

* :ref:`Schackman et al., Nature Reviews Neuroscience (2011) <SSS+11>`: The
  integration of negative affect, pain and cognitive control in the cingulate
  cortex.

2010
----

* :ref:`Margulies et al., Magnetic Resonance Materials in Physics, Biology and
  Medicine (2010) <MBL+10>`: Resting developments: a review of fMRI
  post-processing methodologies for spontaneous brain activity.

* :ref:`Shiffrin, Topics in Cognitive Science, (2010) <Shi10>`: Perspectives on
  Modeling in Cognitive Science.

* :ref:`LaConte, NeuroImage (2010) <LaC10>`: Decoding fMRI brain states in
  real-time.

* :ref:`Legge & Badii, Proceedings of the 2nd International Conference on
  Emerging Network Intelligence (2010) <LB10>`: An Application of Pattern
  Matching for the Adjustment of Quality of ServiceMetrics.

2009
----

* :ref:`Spacek et al., The Neuromorphic Engineer (2009) <SS09>`: Python in
  Neuroscience.

* :ref:`Bandettini, Journal of Integrative Neuroscience (2009) <Ban09>`: Seven
  topics in functional magnetic reasonance imaging.

* :ref:`Garcia et al., Frontiers in Neuroinformatics (2009) <GF09>`:
  OpenElectrophy: An Electrophysiological Data- and Analysis-Sharing Framework.

* :ref:`Mur et al., Social Cognitive and Affective Neuroscience (2009)
  <MBK09>`: Revealing representational content with pattern-information fMRI –
  an introductory guide.

* :ref:`Pereira et al., NeuroImage (2009) <PMB09>`: Machine learning
  classifiers and fMRI: A tutorial overview.
